# Cartils

Cartils is a simple utility package full of various useful and not-so-useful functions

## To Do
- [x] RLE encoding
- [x] Animation
    - [x] Sync
    - [x] Async
    - [x] Looping
- [x] Logger
- [x] Check if program installed
- [x] Run external program